==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/kubernetesconfiguration/kotlin/inputs/RepositoryRefDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kubernetesconfiguration.kotlin.inputs

import com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The source reference for the GitRepository object.
 * @property branch The git repository branch name to checkout.
 * @property commit The commit SHA to checkout. This value must be combined with the branch name to be valid. This takes precedence over semver.
 * @property semver The semver range used to match against git repository tags. This takes precedence over tag.
 * @property tag The git repository tag name to checkout. This takes precedence over branch.
 */
public data class RepositoryRefDefinitionArgs(
    public val branch: Output<String>? = null,
    public val commit: Output<String>? = null,
    public val semver: Output<String>? = null,
    public val tag: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs =
        com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs.builder()
            .branch(branch?.applyValue({ args0 -> args0 }))
            .commit(commit?.applyValue({ args0 -> args0 }))
            .semver(semver?.applyValue({ args0 -> args0 }))
            .tag(tag?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RepositoryRefDefinitionArgs].
 */
@PulumiTagMarker
public class RepositoryRefDefinitionArgsBuilder internal constructor() {
    private var branch: Output<String>? = null

    private var commit: Output<String>? = null

    private var semver: Output<String>? = null

    private var tag: Output<String>? = null

    /**
     * @param value The git repository branch name to checkout.
     */
    @JvmName("fgjqhplobbovudjt")
    public suspend fun branch(`value`: Output<String>) {
        this.branch = value
    }

    /**
     * @param value The commit SHA to checkout. This value must be combined with the branch name to be valid. This takes precedence over semver.
     */
    @JvmName("lpemkinndmqfkvva")
    public suspend fun commit(`value`: Output<String>) {
        this.commit = value
    }

    /**
     * @param value The semver range used to match against git repository tags. This takes precedence over tag.
     */
    @JvmName("leicfohuyrntrqyn")
    public suspend fun semver(`value`: Output<String>) {
        this.semver = value
    }

    /**
     * @param value The git repository tag name to checkout. This takes precedence over branch.
     */
    @JvmName("innuaimpgtedngqq")
    public suspend fun tag(`value`: Output<String>) {
        this.tag = value
    }

    /**
     * @param value The git repository branch name to checkout.
     */
    @JvmName("rlwigwjvupiewftb")
    public suspend fun branch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.branch = mapped
    }

    /**
     * @param value The commit SHA to checkout. This value must be combined with the branch name to be valid. This takes precedence over semver.
     */
    @JvmName("xfeysoltfobprfnr")
    public suspend fun commit(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value The semver range used to match against git repository tags. This takes precedence over tag.
     */
    @JvmName("banuctbxdfpjipwl")
    public suspend fun semver(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.semver = mapped
    }

    /**
     * @param value The git repository tag name to checkout. This takes precedence over branch.
     */
    @JvmName("wvbkwqybauebifaj")
    public suspend fun tag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tag = mapped
    }

    internal fun build(): RepositoryRefDefinitionArgs = RepositoryRefDefinitionArgs(
        branch = branch,
        commit = commit,
        semver = semver,
        tag = tag,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/kubernetesconfiguration/kotlin/inputs/RepositoryRefDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kubernetesconfiguration.kotlin.inputs

import com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The source reference for the GitRepository object.
 * @property branch The git repository branch name to checkout.
 * @property commit The commit SHA to checkout. This value must be combined with the branch name to be valid. This takes precedence over semver.
 * @property semver The semver range used to match against git repository tags. This takes precedence over tag.
 * @property tag The git repository tag name to checkout. This takes precedence over branch.
 */
public data class RepositoryRefDefinitionArgs(
    public val branch: Output<String>? = null,
    public val commit: Output<String>? = null,
    public val semver: Output<String>? = null,
    public val tag: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs =
        com.pulumi.azurenative.kubernetesconfiguration.inputs.RepositoryRefDefinitionArgs.builder()
            .branch(branch?.applyValue({ args0 -> args0 }))
            .commit(commit?.applyValue({ args0 -> args0 }))
            .semver(semver?.applyValue({ args0 -> args0 }))
            .tag(tag?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RepositoryRefDefinitionArgs].
 */
@PulumiTagMarker
public class RepositoryRefDefinitionArgsBuilder internal constructor() {
    private var branch: Output<String>? = null

    private var commit: Output<String>? = null

    private var semver: Output<String>? = null

    private var tag: Output<String>? = null

    /**
     * @param value The git repository branch name to checkout.
     */
    @JvmName("hlawlgtogcnttgpr")
    public suspend fun branch(`value`: Output<String>) {
        this.branch = value
    }

    /**
     * @param value The commit SHA to checkout. This value must be combined with the branch name to be valid. This takes precedence over semver.
     */
    @JvmName("mawiextfskfcmqvw")
    public suspend fun commit(`value`: Output<String>) {
        this.commit = value
    }

    /**
     * @param value The semver range used to match against git repository tags. This takes precedence over tag.
     */
    @JvmName("ysielmlmewmxgepu")
    public suspend fun semver(`value`: Output<String>) {
        this.semver = value
    }

    /**
     * @param value The git repository tag name to checkout. This takes precedence over branch.
     */
    @JvmName("aajxdkidwlneyogj")
    public suspend fun tag(`value`: Output<String>) {
        this.tag = value
    }

    /**
     * @param value The git repository branch name to checkout.
     */
    @JvmName("tvbbdeeyntepaaoc")
    public suspend fun branch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.branch = mapped
    }

    /**
     * @param value The commit SHA to checkout. This value must be combined with the branch name to be valid. This takes precedence over semver.
     */
    @JvmName("owihgmmfjbntrdlj")
    public suspend fun commit(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value The semver range used to match against git repository tags. This takes precedence over tag.
     */
    @JvmName("dbeejescmacaiksn")
    public suspend fun semver(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.semver = mapped
    }

    /**
     * @param value The git repository tag name to checkout. This takes precedence over branch.
     */
    @JvmName("kpyqoufqtdbhhfpr")
    public suspend fun tag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tag = mapped
    }

    internal fun build(): RepositoryRefDefinitionArgs = RepositoryRefDefinitionArgs(
        branch = branch,
        commit = commit,
        semver = semver,
        tag = tag,
    )
}
